@@ -12,7 +12,7 @@ our @EXPORT = qw(AUTOLOAD);
 use Symbol;
 use POSIX;
 
-our $VERSION = '3.45';
+our $VERSION = '4.56';
 
 sub AUTOLOAD {
   my @names = grep { /^(?:\w+|\w+::\w+)$/ } keys %::;
@@ -42,14 +42,13 @@ symbol table is instead called.
 
 =head1 AUTHOR
 
-Jeremy Mates, E<lt>jmates@cpan.orgE<gt>
+thrig - Jeremy Mates (cpan:JMATES) C<< <jmates at cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Jeremy Mates
+Copyright (C) 2013,2015 by Jeremy Mates
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.16 or, at
-your option, any later version of Perl 5 you may have available.
+This module is free software; you can redistribute it and/or modify it
+under the Artistic License (2.0).
 
 =cut
